import React from "react";
import PropTypes from "prop-types";
import { makeStyles } from "@material-ui/core/styles";
import Accordion from "@material-ui/core/Accordion";
import AccordionSummary from "@material-ui/core/AccordionSummary";
import AccordionDetails from "@material-ui/core/AccordionDetails";
import Checkbox from "@material-ui/core/Checkbox";
import FormControlLabel from "@material-ui/core/FormControlLabel";
import Typography from "@material-ui/core/Typography";
import ExpandMoreIcon from "@material-ui/icons/ExpandMore";
import withStyles from "@material-ui/core/styles/withStyles";

const IconLeftAccordionSummary = withStyles({
  expandIcon: {
    order: -1
  }
})(AccordionSummary);

const useStyles = makeStyles({
  root: {
    width: "100%"
  }
});

const MachinesAccordionList = ({ machines }) => {
  const classes = useStyles();

  return (
    <div className={classes.root}>
      {machines.map(machine => (
        <Accordion key={`machine-${machine.machineId}`}>
          <IconLeftAccordionSummary
            expandIcon={<ExpandMoreIcon />}
            aria-label="Expand"
            aria-controls="additional-actions1-content"
            id="additional-actions1-header"
            IconButtonProps={{ edge: "start" }}
          >
            <FormControlLabel
              aria-label="Acknowledge"
              onClick={event => event.stopPropagation()}
              onFocus={event => event.stopPropagation()}
              control={<Checkbox />}
              label="I acknowledge that I should stop the click event propagation"
            />
          </IconLeftAccordionSummary>
          <AccordionDetails>
            <Typography color="textSecondary">
              The click event of the nested action will propagate up and expand
              the accordion unless you explicitly stop it.
            </Typography>
          </AccordionDetails>
        </Accordion>
      ))}
    </div>
  );
};

MachinesAccordionList.propTypes = {
  machines: PropTypes.array.isRequired
};

export default MachinesAccordionList;
