import React from "react";
import PropTypes from "prop-types";
import {
  Table,
  TableBody,
  TableCell,
  TableContainer,
  TableHead,
  TableRow
} from "@material-ui/core";
import Paper from "@material-ui/core/Paper";
import MachineContainer from "./MachineContainer";
import { useTranslation } from "react-i18next";

const MachinesTableList = ({ dense, machines }) => {
  const { t } = useTranslation();
  return (
    <TableContainer component={Paper}>
      <Table aria-label="collapsible table" size={dense ? "small" : "medium"}>
        <TableHead>
          <TableRow>
            <TableCell />
            <TableCell>{t("Machine.FullName")}</TableCell>
            <TableCell>{t("Machine.Name")}</TableCell>
            <TableCell>{t("Machine.IP")}</TableCell>
            <TableCell>{t("Machine.MAC")}</TableCell>
            <TableCell align="right" />
          </TableRow>
        </TableHead>
        <TableBody>
          {machines.map(machine => (
            <MachineContainer
              key={`machine-${machine.machineId}`}
              machine={machine}
            />
          ))}
        </TableBody>
      </Table>
    </TableContainer>
  );
};

MachinesTableList.propTypes = {
  dense: PropTypes.bool.isRequired,
  machines: PropTypes.array.isRequired
};

export default MachinesTableList;
